@@ -2,4 +2,4 @@
 Pull requests are always welcomed"""
 
 from pywhatkit.mainfunctions import watch_tutorial_in_English, watch_tutorial_in_Hindi, developer_contact, showHistory, shutdown, cancelShutdown, prnt_sleeptm, check_window, sendwhatmsg, info, playonyt, image_to_ascii_art, search, help 
-from pywhatkit.chr_to_handwriting import download, text_to_handwriting
+from pywhatkit.chr_to_handwriting import text_to_handwriting
